@@ -493,7 +493,7 @@ class Widget(view.Renderable):
         elif len(self.children_deep) > 0 and not isinstance(value, (dict,list)):
             value = dict([
                 (w._id, getattr(value, w._id)) 
-                    for w in self.children_deep if hasattr(value, w._id)
+                    for w in self.children_deep if w._id and hasattr(value, w._id)
                 ])
         return value
 
