@@ -182,7 +182,9 @@ def unflatten_args(child_args):
             for_id = new.setdefault(id, {})
             for_id.setdefault('child_args', {})[rest] = v
         else:
-            new[id] = v
+            for_id = new.setdefault(id,{})
+            for key, val  in v.iteritems():
+                for_id.setdefault(key,val)
 
     convert = set()
     for k,v in new.items():
@@ -210,7 +212,6 @@ def unflatten_args(child_args):
 
 
 
-
 class OrderedSet(list):
     """Set preserving item order."""
 
@@ -257,9 +258,11 @@ class RequestLocalDescriptor(ThreadSafeDescriptor):
                 raise
             else:
                 try:
-                    return self.default()
+                    value = self.default()
                 except TypeError:
-                    return self.default
+                    value = self.default
+                setattr(request_local, self.name, value)
+                return value
 
     def __set__(self, obj, value):
         import tw
